@@ -2,6 +2,6 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from r3sponse.v1.classes.r3sponse import r3sponse
+from r3sponse.v1.classes.r3sponse import r3sponse, ResponseObject
 from r3sponse.v1.classes.utils import symbol, color
 
