@@ -45,9 +45,9 @@ class R3sponse(object):
 		r3sponse.log(message=response["message"], log_level=log_level, save=save)
 		if django: 
 			try:
-				response = JsonResponse(response.json(), safe=False)
-			except:
-				response = JsonResponse(response, safe=False)
+				response = JsonResponse(response.dict(), safe=False)
+			except AttributeError:
+				response = JsonResponse(response)
 		return response
 	def error_response(self,
 		# the error message.
@@ -66,9 +66,9 @@ class R3sponse(object):
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
 		if django: 
 			try:
-				response = JsonResponse(response.json(), safe=False)
-			except:
-				response = JsonResponse(response, safe=False)
+				response = JsonResponse(response.dict(), safe=False)
+			except AttributeError:
+				response = JsonResponse(response)
 		return response
 		#
 	def success(self, response):
